window.argo = {
    /**
     * Update the navigation bar appearance
     *
     * backgroundColor:         hex rgb color value for the background
     * rightBarButtonColor:     hex rgb color value for the right bar button
     * rightBarButtonTitle:     button text for the right bar button
     * rightBarButtonWeight:    button text weight for the right bar button
     * rightBarButtonAction:    action to be performed on tap ("signout"|"signin"|<function_name_on_window>)
     * statusBarTheme:          force the system status bar to be dark or light ("dark"|"light")
     * logoPosition:            move the Netflix logo ("left"|"center")
     */
    updateNavigationBar : function(args) {
        if(!args || Object.keys(args).length === 0) {
            return;
        }
        window.webkit.messageHandlers.updateNavigationBar.postMessage(args);
    },
    
    /**
     * Reset the navigation bar, undoing all the updates performed with updateNavigationBar.
     */
    resetNavigationBar : function() {
        window.webkit.messageHandlers.updateNavigationBar.postMessage();
    },
    
    /**
     * Called by Quicksilver to make Argo tokenActivate.
     * Once activation has finished Argo will attempt to execute 
     * window.argoActivationCompleted({success:)
     */
    signUpCompleted: function(tokens) {
        window.webkit.messageHandlers.signUpCompleted.postMessage(tokens);
    },

    tokenActivate: function() {
        window.webkit.messageHandlers.tokenActivate.postMessage();
    },
    
    /**
     * Launch the Mobile Safari app with url
     *
     * url:                 url to load
     * useAutoLoginTokens:  if true, add token=<auto_login_token> to the request
     */
    launchMobileSafari: function(url, useAutoLoginTokens) {
        var args = {
            "url" : url,
            "autologin" : useAutoLoginTokens
        };
        window.webkit.messageHandlers.launchMobileSafari.postMessage(args);
    },
    
    /**
     * Notify native app that the UI is loaded and ready.
     */
    notifyOnReady : function(args) {
        window.webkit.messageHandlers.notifyOnReady.postMessage(args);
    },
    
    /**
     * Notify native app that the UI has finished rendering.
     */
    notifyOnRendered : function(args) {
        window.webkit.messageHandlers.notifyOnRendered.postMessage(args);
    },
    
    /**
     * Tell native app to take the user to the Sign In page.
     */
    toSignIn : function(args) {
        window.webkit.messageHandlers.toSignIn.postMessage(args)
    },
    
    /**
     * Tell native app to show a native Alert dialog with a single button that dismisses the alert.
     * The args should have:
     * title: String. Optional. If not present, the dialog won't have a title.
     * message: String. Required. If not present, the dialog won't show.
     * okText: String. Optional. If not present, the button will say "OK" (localized)
     */
    showDialog : function(args) {
        window.webkit.messageHandlers.showDialog.postMessage(args)
    },
    
    showLoginWithNeverMemberCookies : function() {
        var args = {
            cookie : document.cookie
        };
        window.webkit.messageHandlers.showLoginWithNeverMemberCookies.postMessage(args);
    },

    /**
     * Start non-member video playback in the native video player.
     *
     * entityId:  the video ID of the playable
     */
    playVideo : function(args) {
        if (!args) {
            args = {
                entityId : 70248289,
                trackId  : 0,
                type     : 'episode',
                membershipStatus: 'NON_REGISTERED_MEMBER'
            };
        }
        window.webkit.messageHandlers.playVideo.postMessage(args);
    },

    logIDFAEvent : function(args) {
        if (args && args["name"]) {
            window.webkit.messageHandlers.logIDFAEvent.postMessage(args);
        }
    },

    showSkipProfilesGateFlag : function(args) {
        window.webkit.messageHandlers.showSkipProfilesGateFlag.postMessage(args);
    },

    signOutOfApp : function(args) {
        window.webkit.messageHandlers.signOutOfApp.postMessage(args);
    },
    
    purchaseWithMocking: function(args, cb) {
        window.__PURCHASE_WITH_MOCKING_CALLBACK__ = cb;
        
        window.webkit.messageHandlers.purchaseWithMocking.postMessage(args);
    }
};
